@@ -65,6 +65,7 @@ GtkTreeModel *he_menu_store_new(GtkMenu *menu);
  * @HE_MENU_STORE_INCONSISTENT: Index of the column indicating wheather this #GtkCheckMenuItem is inconsistent
  * @HE_MENU_STORE_MENU_WIDGET: Index of the column containing the #GtkMenuItem
  * @HE_MENU_STORE_HAS_CHILDREN: Index of the column indicating wheather this #GtkCheckMenuItem has a submenu
+ * @HE_MENU_STORE_MARKUP: Index of the column  where the markup is stored. If the menu item has no markup then this column contains the same text as %HE_MENU_STORE_TEXT
  * @HE_MENU_STORE_N_COLUMNS: Number of columns in a #HeMenuStore
  *
  * These are the column indices and the column count of a #HeMenuStore.
@@ -81,6 +82,7 @@ typedef enum {
 	HE_MENU_STORE_INCONSISTENT,
 	HE_MENU_STORE_MENU_WIDGET,
 	HE_MENU_STORE_HAS_CHILDREN,
+	HE_MENU_STORE_MARKUP,
 	HE_MENU_STORE_N_COLUMNS
 } HeMenuStoreColumn;
 //HE_MENU_STORE_IMAGE_GICON,
