@@ -223,9 +223,14 @@ destroy_excess_columns(HeMenuView *hmv, int alloc_width, gboolean tail_is_signif
 		}
 
 		do {
-			keep_looping = (ll_itr != (*p_end));
-			gtk_widget_destroy(GTK_WIDGET((*p_end)->data));
-			(*pop_fn)(hmv->priv->menu_q);
+			/* Never empty the queue completely */
+			if (hmv->priv->menu_q->length > 1) {
+				keep_looping = (ll_itr != (*p_end));
+				gtk_widget_destroy(GTK_WIDGET((*p_end)->data));
+				(*pop_fn)(hmv->priv->menu_q);
+			}
+			else
+				keep_looping = FALSE;
 		} while (keep_looping);
 	}
 
@@ -490,30 +495,41 @@ unset_borders(GtkWidget *widget, gpointer null)
 	}
 }
 
+typedef struct {
+	GtkWidget *dlg;
+	GtkMenuItem *item;
+	GtkMenu *menu;
+} DialogHasDiedParams;
+
 /*
  * Only activate the menu item after the dialog has disappeared. This helps prevent the popup dialog from having an effect on
  * dialogs that may be popped up as a result of the action of the menu item.
  */
 static void
-dialog_has_died(GtkMenuItem *menu_widget, gpointer dead_dialog)
+dialog_has_died(DialogHasDiedParams *params, gpointer dead_dialog)
 {
-	gtk_menu_item_activate(menu_widget);
-	g_object_unref(G_OBJECT(menu_widget));
+	if (params->item) {
+		gtk_menu_item_activate(params->item);
+		g_object_unref(G_OBJECT(params->item));
+	}
+	if (params->menu) {
+		g_signal_emit_by_name(G_OBJECT(params->menu), "deactivate");
+		g_object_unref(params->menu);
+	}
+	g_free(params);
 }
 
 /*
  * The user has chosen a #GtkMenuItem. Destroy the dialog and set up its activation upon the dialog's destruction.
  */
 static void
-menu_widget_notify(HeMenuView *hmv, GParamSpec *pspec, GtkWidget *dlg)
+menu_widget_notify(HeMenuView *hmv, GParamSpec *pspec, DialogHasDiedParams *params)
 {
 	GtkWidget *menu_widget = he_menu_view_get_menu_widget(hmv);
 
-	if (menu_widget) {
-		g_object_ref(menu_widget);
-		g_object_weak_ref(G_OBJECT(dlg), (GWeakNotify)dialog_has_died, menu_widget);
-	}
-	gtk_widget_destroy(dlg);
+	if (menu_widget)
+		params->item = g_object_ref(menu_widget);
+	gtk_widget_destroy(params->dlg);
 }
 
 /*
@@ -524,6 +540,7 @@ pop_dialog(GtkWindow *parent, GtkMenu *menu, gboolean run)
 {
 	GtkWidget *hmv;
 	GtkWidget *dlg;
+	DialogHasDiedParams *params = g_new0(DialogHasDiedParams, 1);
 
 	hmv = g_object_new(HE_TYPE_MENU_VIEW, "visible", TRUE, "menu", menu, "do-activate", FALSE, NULL);
 
@@ -533,11 +550,16 @@ pop_dialog(GtkWindow *parent, GtkMenu *menu, gboolean run)
 		(GDestroyNotify)g_source_remove);
 	g_signal_connect(G_OBJECT(dlg), "delete-event", (GCallback)dlg_ignore_delete, NULL);
 
+	params->dlg = dlg;
+	params->menu = g_object_ref(menu);
+
 	unset_borders(GTK_BIN(dlg)->child, NULL);
 
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dlg)->vbox), hmv);
 
-	g_signal_connect(G_OBJECT(hmv), "notify::menu-widget", (GCallback)menu_widget_notify, dlg);
+	g_object_weak_ref(G_OBJECT(dlg), (GWeakNotify)dialog_has_died, params);
+
+	g_signal_connect(G_OBJECT(hmv), "notify::menu-widget", (GCallback)menu_widget_notify, params);
 
 	if (run)
 		gtk_dialog_run(GTK_DIALOG(dlg));
